==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GridCellPositionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridCellPositionDescription } from "./GridCellPositionDescription";
/**
 * @hidden
 */
export let GridCellPositionDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellPositionDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellPositionDescriptionMetadata.a == null) {
                GridCellPositionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellPositionDescriptionMetadata.c(GridCellPositionDescriptionMetadata.a);
            }
            if (a.j(GridCellPositionDescriptionMetadata.a)) {
                return;
            }
            a.y(GridCellPositionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("RowIndex", "Number:int");
            a.item("ColumnUniqueKey", "String");
        }
        static d(a) {
            GridCellPositionDescriptionMetadata.b(a);
            a.aa("GridCellPosition", () => new GridCellPositionDescription());
            a.z("GridCellPosition", GridCellPositionDescriptionMetadata.a);
        }
    }
    GridCellPositionDescriptionMetadata.$t = /*@__PURE__*/ markType(GridCellPositionDescriptionMetadata, 'GridCellPositionDescriptionMetadata');
    GridCellPositionDescriptionMetadata.a = null;
    return GridCellPositionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridCellPositionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridCellPositionDescription } from "./GridCellPositionDescription";
/**
 * @hidden
 */
export let GridCellPositionDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellPositionDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellPositionDescriptionMetadata.a == null) {
                GridCellPositionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellPositionDescriptionMetadata.c(GridCellPositionDescriptionMetadata.a);
            }
            if (a.k(GridCellPositionDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridCellPositionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("RowIndex", "Number:int");
            a.item("ColumnUniqueKey", "String");
        }
        static d(a) {
            GridCellPositionDescriptionMetadata.b(a);
            a.ac("GridCellPosition", () => new GridCellPositionDescription());
            a.ab("GridCellPosition", GridCellPositionDescriptionMetadata.a);
        }
    }
    GridCellPositionDescriptionMetadata.$t = /*@__PURE__*/ markType(GridCellPositionDescriptionMetadata, 'GridCellPositionDescriptionMetadata');
    GridCellPositionDescriptionMetadata.a = null;
    return GridCellPositionDescriptionMetadata;
})();
